("a modifier" "a mdostbillenty")
("a series" "")
("abbreviation" "rvidts")
("about" "nvjegy")
("about menu" "nvjegy men")
("above" "fellre")
("abstract" "kivonat")
("accent" "kezet")
("accept" "elfogads")
("accept all scripts" "az sszes szkript elfogadsa")
("accept no scripts" "szkriptek elutastsa")
("accept script" "szkript elfogadsa")
("account" "hozzfrs")
("acknowledgment" "ksznetnyilvnts")
("acronym" "betsz")
("action" "akci")
("activate" "aktivls")
("activate once" "aktivls egy alkalomra")
("activate hidden" "")
("activation" "aktivls")
("active link types" "aktv hivatkozstpusok")
("acute" "acute")
("add package" "csomag hozzadsa")
("add switch after" "kapcsol hozzadsa ez utn")
("add switch before" "kapcsol hozzadsa ez el")
("address" "cm")
("address block" "cmblokk")
("advanced" "halad")
("advanced layout features" "halad elrendezsi belltsok")
("after" "ez utn")
("albanian" "albn")
("algorithm" "algoritmus")
("align cell to the bottom" "cella igaztsa alulra")
("align cell to the left" "cella igaztsa balra")
("align cell to the right" "cella igaztsa jobbra")
("align cell to the top" "cella igaztsa fellre")
("align table at base of left column" "tblzat bal oldali oszlophoz igaztsa")
("align table at base of middle column" "tblzat kzps oszlophoz igaztsa")
("align table at base of origin column" "")
("align table at base of right column" "tblzat jobb oldali oszlophoz igaztsa")
("align table at fraction bar height" "tblzat igaztsa a trtvonal magassghoz")
("align table at the base of bottom row" "tblzat als sorhoz igaztsa")
("align table at the base of middle row" "tblzat kzps sorhoz igaztsa")
("align table at the base of origin row" "")
("align table at the base of top row" "tblzat fels sorhoz igaztsa")
("align table at the bottom" "tblzat igaztsa alulra")
("align table at the center" "tblzat igaztsa kzpre")
("align table at the horizontal center" "tblzat igaztsa vzszintesen kzpre")
("align table at the left" "tblzat igaztsa balra")
("align table at the top" "tblzat igaztsa fellre")
("align table to the right" "tblzat igaztsa jobbra")
("align text to the left" "szveg igaztsa balra")
("align text to the right" "szveg igaztsa jobbra")
("aligned" "igaztott")
("alignment" "igazts")
("all" "minden oldal")
("allow" "engedlyezs")
("allow for macro definitions in preamble" "makrdefincik engedlyezse a preamble szakaszban")
("allowed extension" "engedlyezett kiterjeszts")
("allowed reduction" "engedlyezett egyszersts")
("alpha release" "alfa vltozat")
("also on paper" "papron is")
("alt key" "alt billenty")
("alternative specification" "alternatv specifikci")
("always" "mindig")
("american" "amerikai")
("and" "s")
("angular" "angular")
("animation" "animci")
("appendix" "fggelk")
("apply" "alkalmazs")
("apply macro" "makr alkalmazsa")
("apply macro once" "makr alkalmazsa egyszer")
("april" "prilis")
("arab" "arab")
("arc" "v")
("arc cosine" "arkusz koszinusz")
("arc sine" "arkusz szinusz")
("arc tangent" "arkusz tangens")
("arch series" "")
("archaic" "archaikus")
("architecture" "")
("argument" "argumentum")
("arithmetic" "aritmetikai mvelet")
("armenian" "rmny")
("arrow" "nyl")
("arrows" "nyilak")
("article" "cikk")
("as on paper" "mint a papron")
("assign" "")
("at fraction bar height" "trtvonal magassgban")
("at the baseline" "az alapvonalnl")
("at the bottom" "alul")
("at the left" "bal oldalon")
("at the middle" "kzpen")
("at the right" "jobb oldalon")
("at the top" "fell")
("attach" "csatols")
("attach buffer to which project" "melyik projekthez csatoljuk a puffert")
("august" "augusztus")
("author" "szerz")
("authorize" "engedlyezs")
("automatic" "automatikus")
("automatically close brackets" "zrjelek automatikus kiegsztse")
("automatically generated content" "automatikusan ellltott tartalom")
("automatic quotes" "automatikus idzjelek")
("autosave" "automatikus ments")
("axis" "tengely")
("axiom" "axima")
("b series" "")
("back" "vissza")
("background" "httr")
("background color" "httrszn")
("background evaluations" "kirtkelsek a httrben")
("backtrace errors" "hibk visszakvetse")
("backward replace" "csere visszafel")
("backward search" "keress visszafel")
("bad data format" "rossz adatformtum")
("bar" "vzszintes vons")
("bard" "")
("base level" "alapszint")
("baseline" "alapvonal")
("bashkirian" "baskr")
("basic" "egyszer")
("basic communication using pipes" "alapfok kommunikci csvek hasznlatval")
("basic data types" "alapvet adattpusok")
("basic types" "alapvet tpusok")
("be useful" "tegye hasznoss magt")
("become a TeXmacs developer" "lpjen be a TeXmacs fejleszti kz")
("before" "el")
("begin" "kezds")
("below" "alulra")
("beta release" "bta vltozat")
("bibliography" "irodalomjegyzk")
("bibliography file" "irodalomjegyzk fjl")
("bibliography style" "irodalomjegyzk stlus")
("bibtex command" "bibtex parancs")
("bidirectional" "ktirny")
("big" "nagy")
("big figure" "nagy bra")
("big operator" "nagy opertor")
("big skip" "nagy helykihagys")
("big table" "nagy tblzat")
("binary operation" "binris mvelet")
("binary relation" "binris relci")
("black" "fekete")
("blackboard bold" "")
("blackboard math" "")
("blackletter" "")
("blank column" "res oszlop")
("blank row" "res sor")
("block content" "blokktartalom")
("blue" "kk")
("body" "test")
("bold" "flkvr")
("book" "knyv")
("border" "keret")
("both" "mindkett")
("bottom" "alul")
("bottom border" "keret alul")
("bottom cell border" "cellakeret alul")
("bottom cell padding" "cella-helykihagys alul")
("bottom margin" "als marg")
("bottom padding" "helykihagys alul")
("bottom table border" "als tblzatkeret")
("bottom table padding" "tblzat-helykihagys alul")
("branch" "g")
("break" "trspont")
("breaking" "trs")
("breve" "breve")
("british" "brit angol")
("broken white" "trtfehr")
("brown" "barna")
("browse" "bngszs")
("browse web" "a web bngszse")
("browser" "bngsz")
("buffer" "puffer")
("bulgarian" "bolgr")
("bullet" "goly")
("bullets" "golyk")
("by" "ksztette:")
("by typing" "")
("bytes free" "szabad bjt")
("bytes used" "felhasznlt bjt")
("calculus" "kalkulus")
("calligraphic" "kalligrafikus")
("cancel" "mgsem")
("caps-lock key" "caps-lock billenty")
("cartesian" "descartes-i")
("case" "")
("cc" "")
("cell" "cella")
("cell background color" "cella httrszne")
("cell border" "cellakeret")
("cell height" "cellamagassg")
("cell operation mode" "cella mkdsi md")
("cell width" "cellaszlessg")
("cells" "cellk")
("center" "kzpre")
("center text" "szveg kzpre zrsa")
("centered" "kzpre zrt")
("centered block" "kzpre igaztott blokk")
("centered tabular" "kzpre igaztott tblzatos krnyezet")
("change border of cell" "cella keretnek megvltoztatsa")
("change cell operation mode" "cella mkdsi mdjnak megvltoztatsa")
("change log" "vltozsnapl")
("change the border of the table" "tblzat keretnek megvltoztatsa")
("changes" "vltozsok")
("chapter" "fejezet")
("chat" "csevegs")
("check" "ellenrzs")
("check text for spelling errors" "helyesrs-ellenrzs a szvegben")
("chinese" "knai")
("choice" "vlaszts")
("circle" "kr")
("citation" "idzet")
("cite" "idzs")
("class" "osztly")
("clear" "trls")
("clear selection" "kijells trlse")
("clipped" "levgott")
("clipped and magnified" "levgott s nagytott")
("clipped and resized" "levgott s tmretezett")
("clone" "kettzs")
("clone window" "ablak dupliklsa")
("close" "bezrs")
("close TeXmacs" "a TeXmacs bezrsa")
("close buffer" "a puffer bezrsa")
("close document" "a dokumentum bezrsa")
("close session" "kls munkamenet bezrsa")
("close window" "az ablak bezrsa")
("closed spline" "zrt spline")
("closing" "lezrs")
("closing style" "lezr stlus")
("code" "kd")
("color" "szn")
("column" "oszlop")
("column contains glued items" "")
("column to the left" "oszlop a bal oldalra")
("column to the right" "oszlop a jobb oldalra")
("columns" "oszlop")
("common formats" "oszlopformtumok")
("compact" "tmr")
("compactification" "tmrts")
("compactify" "tmrts")
("compatibility with other formats" "ms formtumokkal val kompatibilits")
("compile article" "cikk szerkesztse")
("compile book" "knyv szerkesztse")
("compile buffer" "puffer szerkesztse")
("compile project" "projekt szerkesztse")
("completion" "kiegszts")
("complex" "komplex")
("concrete" "concrete")
("condensed" "condensed")
("condition" "felttel")
("configuration" "bellts")
("connect" "csatlakozs")
("contact" "elrhetsgek")
("content" "tartalom")
("content tag" "tartalomjelz cmke")
("context dependent icons" "helyzetfgg ikonok")
("continuation of" "folytatsa")
("contract logarithms" "logaritmusok sszevonsa")
("contribute" "hozzjruls")
("control the evaluation of expressions" "kifejezsek kirtkelsnek irnytsa")
("convention" "konvenci")
("converters" "talaktk")
("converters to other data formats" "egyb adatformtumok talakti")
("cosine" "koszinusz")
("copy" "msols")
("copy text" "sz
veg msolsa")
("copy to" "msols ide")
("copying" "msols")
("corollary" "kvetkezmny")
("correct text" "szveg javtsa")
("create" "ltrehozs")
("create a new document" "j dokumentum ltrehozsa")
("create chatroom" "csevegszoba ltrehozsa")
("create link" "hivatkozs ltrehozsa")
("create preamble" "preamble szakasz ksztse")
("create web site" "weboldal ltrehozsa")
("cursors" "kurzorok")
("curve" "grbe")
("custom tab" "testreszabott tabultor")
("customize" "testreszabs")
("customizing TeXmacs" "a TeXmacs testreszabsa")
("customizing the TeXmacs styles" "a TeXmacs stlusok testreszabsa")
("custum tab" "testreszabott tabultor")
("cut" "kivgs")
("cut text" "szveg kivgsa")
("cut to" "kivgs ide")
("cypriot" "ciprusi")
("cyrillic" "cirill")
("cyrillic input method" "cirill szvegbevitel")
("cyrillic italic right" "jobbra dlt cirill")
("czech" "cseh")
("dancers" "")
("danish" "dn")
("dark grey" "sttszrke")
("dash" "ktjel")
("dashes" "ktjelek")
("data conversion" "adattalakts")
("data format" "adatformtum")
("date" "dtum")
("deactivate" "inaktivls")
("deactivate table" "tblzat inaktivlsa")
("december" "december")
("decimal comma" "tizedesvessz")
("decimal dot" "tizedespont")
("decorate atoms" "alapegysgek dsztse")
("default" "alaprtelmezs")
("default padding" "alaprtelmezett helykihagys")
("definition" "definci")
("delete" "trls")
("delete column" "oszlop trlse")
("delete link" "hivatkozs trlse")
("delete row" "sor trlse")
("denominator" "nevez")
("description" "lers")
("destination" "cl")
("detach" "levlaszts")
("detailed" "rszletes")
("detailed menus" "rszletes menk")
("details in menus" "menk rszletessge")
("determinant" "determinns")
("devangari" "devangari")
("developers guide" "fejleszti kziknyv")
("differentiate" "differencils")
("directory" "knyvtr")
("disable" "nincs")
("disable first indentation" "els sor behzsnak letiltsa")
("disable first indentation after" "els sor behzsnak letiltsa ez utn")
("disable first indentation before" "els sor behzsnak letiltsa ez eltt")
("disable indentation" "behzs letiltsa")
("disable indentation after" "behzs letiltsa ez utn")
("disable indentation before" "behzs letiltsa ez eltt")
("deactivate" "inaktivls")
("deactivate once" "inaktivls egyszer")
("disallow" "megtagads")
("disk" "tele kerek")
("distribute unused space" "kihasznlatlan hely elosztsa")
("div" "")
("do not remap" "eredeti funkci")
("document" "dokumentum")
("document format" "dokumentumformtum")
("document style" "dokumentumstlus")
("document styles" "dokumentumstlusok")
("documentation" "dokumentci")
("documents are trees" "a dokumentumok faszerkezetek")
("dot" "pont")
("dots" "pontok")
("double stroke" "dupla vons")
("down" "le")
("download" "letlts")
("dpi" "dpi")
("draw image" "bra rajzolsa")
("draw over selection" "rajzols a kijellsre")
("duplicate" "kettzs")
("dutch" "holland")
("dynamic libraries" "dinamikus knyvtrak")
("edit" "szerkeszts")
("edit grid" "rcs szerkesztse")
("edit source tree" "forrsfa szerkesztse")
("editing tools" "szerkeszteszkzk")
("eigenvalues" "sajtrtkek")
("email" "e-mail")
("email address" "e-mail cm")
("emphasize" "hangslyozs")
("emphasize text" "szveg hangslyozsa")
("empty box" "res doboz")
("enable change" "engedlyezett vltoztatsok")
("enable first indentation" "els sor behzsnak engedlyezse")
("enable first indentation after" "els sor behzsnak engedlyezse ez utn")
("enable first indentation before" "els sor behzsnak engedlyezse ez eltt")
("enable indentation" "behzs engedlyezse")
("enable indentation after" "behzs engedlyezse ez utn")
("enable indentation before" "behzs engedlyezse ez eltt")
("encl" "")
("encoding" "karakterkdols")
("end" "vge")
("english" "angol")
("enlarge selection" "kijells nagytsa")
("enter a title" "adja meg a cmet")
("entire table" "teljes tblzat")
("enumerate" "szmozs")
("enumerate|Alpha" "")
("enumerate|Roman" "")
("enumerate|alpha" "")
("enumerate|roman" "")
("env" "")
("environment" "krnyezet")
("epilogue" "utsz")
("equal" "egyenl")
("equation" "egyenlet")
("equations" "egyenletek")
("equivalent for" "ekvivalens a kvetkezvel:")
("error" "hiba")
("esperanto" "eszperant")
("etruscan" "etruszk")
("evaluate" "kirtkels")
("evaluate scheme expression" "scheme kifejezs kirtkelse")
("evaluation switch" "kirtkels kapcsol")
("evaluation tag" "kirtkels cmke")
("even page footer" "pros oldal lblce")
("even page header" "pros oldal fejlce")
("even page margin" "pros oldal margja")
("even page left margin" "pros oldal bal oldali margja")
("even page shift" "")
("even page text" "szveg pros oldalon")
("exact" "pontosan")
("exact horizontal" "pontosan vzszintes")
("exact mode" "pontos md")
("exam" "vizsga")
("example" "plda")
("exclusive" "kizrlagos")
("exclusive or" "kizr vagy")
("executable" "vgrehajthat")
("execute" "vgrehajts")
("execute a TeXmacs command" "TeXmacs parancs vgrehajtsa")
("execute system command" "rendszerparancs vgrehajtsa")
("executive" "executive")
("exercise" "gyakorlat")
("expand" "kibonts")
("expand logarithms" "logaritmusok kibontsa")
("expand trigonometric functions" "trigonometrikus fggvnyek kibontsa")
("expand unrecognized macros" "ismeretlen makrk kibontsa")
("expand user-defined macros" "felhasznl ltal definilt makrk kibontsa")
("explained" "magyarzott")
("exponential" "kitev")
("export" "exportls")
("export as" "exportls mint")
("export bibliographies as links" "irodalomjegyzk-bejegyzsek exportlsa linkknt")
("export current file" "aktulis fjl exportlsa")
("export formulas as images" "kpletek exportlsa kpknt")
("extend or normal" "kiterjesztett vagy normlis")
("extents" "kiterjeds")
("extern " "kls")
("external" "kls")
("extra" "extra")
("extract format" "formtum kivonatolsa")
("factor" "tnyez")
("family" "csald")
("february" "februr")
("figure" "bra")
("file" "fjl")
("file information" "fjlinformci")
("file name" "fjlnv")
("file not found" "a fjl nem tallhat")
("files" "fjlok")
("fill color" "kitlts szne")
("find next match" "kvetkez tallat")
("find text" "szveg keresse")
("finnish" "finn")
("first contact" "")
("first indentation" "els sor behzsa")
("first item" "els bejegyzs")
("first page" "els oldal")
("first start" "els indts")
("fixed" "rgztett")
("flat" "lapos")
("flexibility" "rugalmassg")
("flexibility factor for vertical spacing" "fggleges helykihagys rugalmassgi tnyezje")
("floating figure" "lebeg bra")
("floating object" "lebeg objektum")
("floating table" "lebeg tblzat")
("fold" "letakars")
("fold input field" "beviteli mez letakarsa")
("folded" "letakart")
("follow external links" "kls hivatkozsok kvetse")
("follow inverse links" "inverz hivatkozsok kvetse")
("font" "bettpus")
("font base size" "bettpus alapmrete")
("font dpi" "bettpus dpi")
("font family" "betcsald")
("font name" "bettpus neve")
("font series" "bettpus sorozat")
("font shape" "bettpus alakja")
("font size" "betmret")
("font type" "bettpus")
("font variant" "betvltozat")
("fonts" "bettpusok")
("footer" "llb")
("footnote" "lbjegyzet")
("for" "")
("foreground" "eltr")
("foreign" "idegen")
("format" "formtum")
("formatted and structured output" "formzott s szerkesztett kimenet")
("formatted date" "formzott dtum")
("formatting" "formzs")
("formula" "kplet")
("formula style" "kpletstlus")
("forward" "elre")
("forward replace" "csere")
("forward search" "keress")
("fraction" "trt")
("frame" "keret")
("french" "francia")
("front matter" "cmlap")
("full screen mode" "teljeskpernys md")
("full manuals" "teljes kziknyvek")
("full name" "teljes nv")
("function" "fggvny")
("functional" "funkcionlis")
("further customization" "tovbbi testreszabs")
("future changes" "jvbeni vltozsok")
("gNU TeXmacs comes without any form of legal warranty" "a GNU TeXmacs-et nem ksri semmifle garancia")
("gNU TeXmacs falls under the GNU general public license" "a GNU TeXmacs a GNU ltalnos Nyilvnos Licenc hatlya al tartozik")
("gcd" "gcd")
("general architecture of TeXmacs" "a TeXmacs ltalnos felptse")
("general negation" "ltalnos tagads")
("general note" "ltalnos megjegyzs")
("generating font file" "a kvetkez bettpusfjl elksztse folyik:")
("generic" "ltalnos")
("geometry" "geometria")
("georgian" "rmny")
("german" "nmet")
("getting started" "els lpsek")
("glossary" "szjegyzk")
("glossary entry" "szjegyzk-bejegyzs")
("glue" "")
("glue decorations" "ragads dsztsek")
("go" "ablak")
("gothic" "gt")
("graphical interface" "grafikus fellet")
("graphics" "grafika")
("grave" "grave")
("greater" "nagyobb")
("greater or equal" "nagyobb vagy egyenl")
("greek" "grg")
("greek letter" "grg bet")
("green" "zld")
("grey" "szrke")
("grids" "rcsok")
("group" "csoportosts")
("h modifier" "h mdostbillenty")
("hang up" "megszakts")
("happy typing" "kellemes munkt")
("has been aborted" "lelltsra kerlt")
("has completed its task" "befejezte feladatt")
("hat" "kalap")
("header" "fejlc")
("header and footer" "fej- s lblc")
("hebrew" "hber")
("height" "magassg")
("height is exactly the specified height" "a magassg pontosan a megadott rtk")
("height is maximum of specified height and box height" "a magassg a megadott rtk s a doboz magassga kzl a nagyobb")
("height is minimum of specified height and box height" "a magassg a megadott rtk s a doboz magassga kzl a kisebbik")
("height magnification" "magassg nagytsa")
("help" "segtsg")
("help me" "")
("help us" "segtsen neknk")
("here" "itt")
("hidden" "rejtett")
("home" "sajt knyvtr")
("home directory" "sajt knyvtr")
("home page" "honlap")
("homepage" "honlap")
("horizontal" "vszintes")
("horizontal alignment" "vzszintes igazts")
("horizontal cell alignment" "vzszintes cellaigazts")
("horizontal ink separation" "")
("horizontal part" "vzszintes rsz")
("horizontal position" "vzszintes helyzet")
("horizontal space" "vzszintes trkz")
("horizontal table alignment" "vzszintes tblzatigazts")
("horizontally align cell to the base" "cella vzszintes igaztsa az alaphoz")
("horizontally center the cell" "cella kzpre igaztsa vzszintesen")
("how much longer may pages become" "mennyivel lehetnek hosszabbak az oldalak")
("how much shorter may pages become" "mennyivel lehetnek rvidebbek az oldalak")
("huge" "risi")
("hungarian" "magyar")
("hybrid command" "hibrid parancs")
("hyperlink" "hiperhivatkozs")
("hyphenation" "elvlaszts")
("icelandic" "izlandi")
("if" "if")
("if hyphenated" "ha el van vlasztva")
("image" "kp")
("image links" "kphivatkozsok")
("implementation" "megvalsts")
("import" "importls")
("import current file" "aktulis fjl importlsa")
("improving the current implementation" "a jelenlegi implementci tkletestse")
("in popup windows" "felugr ablakokban")
("inactive" "inaktv")
("include" "hivatkozs fjlra")
("include a document" "dokumentum beillesztse")
("include file" "fjl beillesztse")
("inclusion into TeXmacs" "beilleszts a TeXmacs szoftverbe")
("inclusions" "beillesztsek")
("indent" "behzs")
("indentation flag" "behzsjelz")
("index" "trgymutat")
("index entry" "trgymutat-bejegyzs")
("index level" "trgymutat szint")
("informative flags" "tjkoztat jelzsek")
("inline arguments" "sorkzi argumentumok")
("input mode" "beviteli md")
("insert" "beszrs")
("insert Pr" "Pr beszrsa")
("insert a TeXmacs symbol" "TeXmacs szimblum beszrsa")
("insert a big operator" "nagy opertor beszrsa")
("insert a binary operation" "binris opertor beszrsa")
("insert a binary relation" "binris relci beszrsa")
("insert a blackboard bold character" "")
("insert a bold calligraphic character" "flkvr kalligrafikus karakter beszrsa")
("insert a bold character" "flkvr karakter beszrsa")
("insert a calligraphic character" "kalligrafikus karakter beszrsa")
("insert a condition" "felttel beszrsa")
("insert a control flow instruction" "vezrlparancs beszrsa")
("insert a fraction" "trt beszrsa")
("insert a fraktur character" "fraktur karakter beszrsa")
("insert a greek character" "grg karakter beszrsa")
("insert a large left delimiter" "")
("insert a large right delimiter" "")
("insert a large separator" "nagy elvlaszt beszrsa")
("insert a left subscript" "bal als index beszrsa")
("insert a link" "hivatkozs beszrsa")
("insert a miscellaneous symbol" "egyb szimblum beszrsa")
("insert a new branch" "j g beszrsa")
("insert a new item" "j bejegyzs beszrsa")
("insert a numerical operation" "numerikus mvelet beszrsa")
("insert a picture" "bra beszrsa")
("insert a square root" "ngyzetgyk beszrsa")
("insert a table" "tblzat beszrsa")
("insert a table or a matrix" "tblzat vagy mtrix beszrsa")
("insert a textual operation" "szvegmvelet beszrsa")
("insert a wide symbol above" "szles szimblum beszrsa fellre")
("insert a wide symbol below" "szles szimblum beszrsa alulra")
("insert an" "")
("insert an accent" "kezet beszrsa")
("insert an arrow" "nyl beszrsa")
("insert an environment" "krnyezet beszrsa")
("insert an n" "n beszrsa")
("insert an operation on tuples" "n-eseken vgzett mvelet beszrsa")
("insert appendix" "fggelk beszrsa")
("insert arccos" "arccos beszrsa")
("insert arcsin" "arcsin beszrsa")
("insert arctan" "arctan beszrsa")
("insert arg" "arg beszrsa")
("insert argument" "argumentum beszrsa")
("insert author" "szerz beszrsa")
("insert automatically generated content" "automatikusan ellltott tartalom beszrsa")
("insert big contour integral" "")
("insert big coproduct" "")
("insert big direct sum" "")
("insert big dotted point" "")
("insert big integral" "nagy integrljel beszrsa")
("insert big intersection" "")
("insert big logical and" "nagy logikai s beszrsa")
("insert big logical or" "nagy logikai vagy beszrsa")
("insert big product" "nagy szorzsjel beszrsa")
("insert big square union" "")
("insert big summation" "nagy szummajel beszrsa")
("insert big tensor product" "nagy tenzorszorzsjel beszrsa")
("insert big union" "")
("insert big union sum" "")
("insert big vertical space" "nagy fggleges trkz beszrsa")
("insert chapter" "fejezet beszrsa")
("insert column" "oszlop beszrsa")
("insert column to the left" "oszlop beszrsa a bal oldalra")
("insert column to the right" "oszlop beszrsa a jobb oldalra")
("insert cos" "cos beszrsa")
("insert cosh" "cosh beszrsa")
("insert cot" "cot beszrsa")
("insert coth" "coth beszrsa")
("insert csc" "csc beszrsa")
("insert deg" "deg beszrsa")
("insert det" "det beszrsa")
("insert dim" "dim beszrsa")
("insert dollar" "dollrjel beszrsa")
("insert equation" "egyenlet beszrsa")
("insert executable markup" "")
("insert exp" "exp beszrsa")
("insert fields" "mezk beszrsa")
("insert footnote" "lbjegyzet beszrsa")
("insert formula" "kplet beszrsa")
("insert gcd" "gcd beszrsa")
("insert hom" "hom beszrsa")
("insert horizontal interword space" "vzszintes szkz beszrsa")
("insert image" "kp beszrsa")
("insert inactive markup" "inaktv jells beszrsa")
("insert inf" "inf beszrsa")
("insert input field above" "beviteli mez beszrsa e fl")
("insert input field below" "beviteli mez beszrsa ez al")
("insert ker" "ker beszrsa")
("insert lg" "lg beszrsa")
("insert lim" "lim beszrsa")
("insert liminf" "liminf beszrsa")
("insert limsup" "limsup beszrsa")
("insert ln" "ln beszrsa")
("insert log" "log beszrsa")
("insert macro" "makr beszrsa")
("insert mathematics" "matematikai szveg beszrsa")
("insert max" "max beszrsa")
("insert medium horizontal space" "kzepes vzszintes trkz beszrsa")
("insert medium vertical space" "kzepes fggleges trkz beszrsa")
("insert min" "min beszrsa")
("insert negative horizontal space" "negatv vzszintes trkz beszrsa")
("insert new item or number" "j bejegyzs vagy szm beszrsa")
("insert new rows or columns" "j sorok vagy oszlopok beszrsa")
("insert or delete rows or columns" "sorok vagy oszlopok beszrsa vagy trlse")
("insert row" "sor beszrsa")
("insert row above" "sor beszrsa e fl")
("insert row below" "sor beszrsa ez al")
("insert sec" "sec beszrsa")
("insert section" "szakasz beszrsa")
("insert sharp" "kettskereszt beszrsa")
("insert sin" "sin beszrsa")
("insert sinh" "sinh beszrsa")
("insert small horizontal space" "kis vzszintes trkz beszrsa")
("insert small vertical space" "kis fggleges trkz beszrsa")
("insert structural markup" "szerkezetjells beszrsa")
("insert subsection" "alfejezet beszrsa")
("insert subsubsection" "al-alfejezet beszrsa")
("insert sup" "sup beszrsa")
("insert tan" "tan beszrsa")
("insert tanh" "tanh beszrsa")
("insert text field" "szvegmez beszrsa")
("insert thick horizontal space" "vastag vzszintes trkz beszrsa")
("insert title" "cm beszrsa")
("insert value" "rtk beszrsa")
("integrate" "integrls")
("interactive command" "interaktv parancs")
("interactive questions" "interaktv krdsek")
("interfacing" "hasznlat felhasznli felletknt")
("interfacing TeXmacs with other systems" "TeXmacs sszekapcsolsa ms rendszerekkel")
("interjection" "kzbevets")
("interline separation" "minimlis sorkz")
("interline space" "sorkz")
("internationalization" "honosts")
("interparagraph space" "bekezdskz")
("interrupt execution" "vgrehajts megszaktsa")
("introduction" "bevezets")
("invert" "invertls")
("invisible" "lthatatlan")
("invisible citation" "lthatatlan idzs")
("irish" "r")
("is running" "fut")
("is tuple" "n-es")
("ispell does not respond" "az ispell nem vlaszol")
("ispell is already busy" "az ispell mr dolgozik")
("italian" "olasz")
("italic" "dlt")
("italic right" "jobbra dlt")
("itemize" "felsorols")
("january" "janur")
("japanese" "japn")
("july" "jlius")
("june" "jnius")
("justified" "sorkizrt")
("justify text" "szveg sorkizrtt ttele")
("keep evaluated expressions" "kirtkelt kifejezse megrzse")
("key" "billenty")
("keyboard" "billentyzet")
("keyboard equivalent" "megfelel billenty")
("keyboard modifiers" "billentymdostk")
("keyboard shortcut" "gyorsbillentyk")
("keymaps" "billentykiosztsok")
("keyword" "kulcssz")
("keywords" "kulcsszavak")
("kill" "lellts")
("known bugs" "ismert programhibk")
("korean" "koreai")
("label" "cmke")
("landscape" "fekv")
("language" "nyelv")
("large" "nagy")
("large closing bracket" "nagy zr zrjel")
("large delimiter" "nagy hatrol")
("large opening bracket" "nagy nyit zrjel")
("large separator" "nagy elvlasztjel")
("last page" "utols oldal")
("latex command" "latex parancs")
("latin" "latin")
("layout" "elrendezs")
("lcm" "lcm")
("left" "bal")
("left arrow" "nyl balra")
("left border" "bal oldali keret")
("left cell border" "bal oldali cellakeret")
("left cell padding" "bal oldali cella-helykihagys")
("left margin" "bal oldali marg")
("left padding" "bal oldali helykihagys")
("left prime" "")
("left aligned" "balra igaztva")
("left slanted" "balra ferde")
("left subscript" "bal als index")
("left superscript" "bal fels index")
("left surrounding" "")
("left table border" "bal oldali tblzatkeret")
("left table padding" "bal oldali tblzat-helykihagys")
("legal" "legal")
("lemma" "segdttel")
("length" "hosszsg")
("less" "kisebb")
("less or equal" "kisebb vagy egyenl")
("letter" "levl")
("license" "licenc")
("light" "vkony")
("light grey" "vilgosszrke")
("limitations" "")
("limits" "")
("line" "sor")
("line break" "sortrs")
("line properties" "vonal tulajdonsgai")
("line stretch" "sor nyjtsa")
("line width" "vonalvastagsg")
("linear algebra" "lineris algebra")
("link" "hivatkozs")
("link image" "hivatkozs kpre")
("link mode" "hivatkozsi md")
("linking tool" "hivatkozskezel eszkz")
("list" "lista")
("list of figures" "brajegyzk")
("list of tables" "tblzatok jegyzke")
("load" "megnyits")
("load LaTeX file" "LaTeX fjl megnyitsa")
("load TeX file" "TeX fjl megnyitsa")
("load TeXmacs file" "TeXmacs fjl megnyitsa")
("load TeXmacs style file" "TeXmacs stlusfjl megnyitsa")
("load a file" "fjl megnyitsa")
("load buffer" "puffer megnyitsa")
("load file" "fjl megnyitsa")
("load html file" "html fjl megnyitsa")
("load image" "kp megnyitsa")
("load in new window" "megnyits j ablakban")
("load latex file" "latex fjl megnyitsa")
("load more recent autosave file" "jabb automatikus ments megnyitsa")
("load tex file" "tex fjl megnyitsa")
("load verbatim file" "verbatim fjl megnyitsa")
("loaded" "betltve")
("locus" "hely")
("logarithm" "logaritmus")
("logarithmic" "logaritmikus")
("logarithms" "logaritmusok")
("login" "bejelentkezs")
("logout" "kijelentkezs")
("long" "hossz")
("look and feel" "kinzet")
("look up" "keress")
("lower border" "keret cskkentse")
("m modifier" "m mdostbillenty")
("macro" "makr")
("magenta" "magenta")
("magic" "")
("magnification" "nagyts")
("magnified" "nagytott")
("main" "fbejegyzs")
("main icon bar" "f ikoneszkztr")
("major changes" "fbb vltozsok")
("make a page insertion" "")
("make a subscript" "als index ksztse")
("make a superscript" "fels index ksztse")
("make acute" "")
("make bar" "")
("make check" "")
("make fraction" "trt ksztse")
("make grave" "")
("make hat" "kalap ksztse")
("make label" "cmke ksztse")
("make negation" "tagads ksztse")
("make page reference" "oldalhivatkozs ksztse")
("make reference" "hivatkozs ksztse")
("make square root" "ngyzetgyk ksztse")
("make tilde" "tilde ksztse")
("make title" "cm ksztse")
("make vector" "vektor ksztse")
("making donations" "adomnyok")
("manual" "kziknyv")
("map to" "legyen")
("march" "mrcius")
("margins" "margk")
("margins as on paper" "margk mint a papron")
("master" "")
("master file" "mesterfjl")
("math" "matematika")
("math font" "matematikai bettpus")
("math font family" "matematikai betcsald")
("math font series" "matematikai betsorozat")
("math font shape" "matamatikai betalak")
("mathematical" "matematikai")
("mathematical and customized input" "matematikai s testreszabott bevitel")
("mathematical font" "matematikai bettpus")
("mathematical formulas" "matematikai kpletek")
("mathematical input" "matematikai szvegbevitel")
("mathematical typesetting" "matematikai szeds")
("mathematics" "matematika")
("matrices" "mtrixok")
("matrix" "mtrix")
("maximal" "maximlis")
("maximal cell height" "maximlis cellamagassg")
("maximal cell width" "maximlis cellaszlessg")
("maximal number of columns" "maximlis oszlopszm")
("maximal number of rows" "maximlis sorszm")
("maximal table height" "tblzat maximlis magassga")
("maximal table width" "tblzat maximlis szlessge")
("maximum mode" "maximum md")
("may" "mjus")
("medium" "kzepes")
("medium skip" "kzepes helykihagys")
("meminfo" "meminfo")
("memory information" "memriainformci")
("merge" "sszeolvaszts")
("messy" "")
("meta key" "meta billenty")
("middle" "kzpre")
("minimal" "minimlis")
("minimal cell height" "minimlis cellamagassg")
("minimal cell width" "minimlis cellaszlessg")
("minimal number of columns" "oszlopok minimlis szma")
("minimal number of rows" "sorok minimlis szma")
("minimal table height" "minimlis tblzatmagassg")
("minimal table width" "minimlis tblzatszlessg")
("minimum mode" "minimum md")
("minus" "mnusz")
("miscellaneous" "egyb")
("miscellaneous features" "egyb tulajdonsgok")
("mod" "mod")
("mode" "md")
("modifier" "mdost")
("modify cell alignment" "cellaigazts mdostsa")
("modify cell border" "cellakeret mdostsa")
("modify cell padding" "cella helykitltsnek mdostsa")
("modify cell size" "cellamret mdostsa")
("modify table border" "tblzatkeret mdostsa")
("modify table padding" "tblzat helykitltsnek mdostsa")
("mongolian" "mongol")
("more information about GNU TeXmacs can be found in the Help" "A GNU TeXmacs-rl tovbbi informci itt: Segtsg")
("mosaic" "")
("move" "mozgats")
("move down" "mozogjon lefel")
("move object" "objektum mozgatsa")
("move to the right when finished" "menjen jobbra, ha ksz")
("move up" "mozgats felfel")
("multiline input" "tbbsoros bevitel")
("mutator tags" "mdostcmkk")
("my documents" "sajt dokumentumaim")
("n-th" "n-edik")
("n-th root" "n-edik gyk")
("name" "nv")
("navigation options" "navigcis opcik")
("negation" "tagads")
("never" "soha")
("new" "j")
("new account" "j hozzfrs")
("new buffer" "j puffer")
("new column" "j oszlop")
("new document" "j dokumentum")
("new double page" "j dupla lap")
("new double page before" "j dupla lap, ez el")
("new file" "j fjl")
("new item" "j bejegyzs")
("new line" "j sor")
("new locus" "j hely")
("new number" "j szm")
("new page" "j lap")
("new page before" "j lap, ez el")
("new paragraph" "j bekezds")
("new roman" "")
("new row" "j sor")
("new table" "j tblzat")
("next" "kvetkez")
("next line" "kvetkez sor")
("nickname" "becenv")
("no changes need to be saved" "nincs mentst ignyl vltoztats")
("no dictionary for" "")
("no first indentation" "els sor behzsnak letiltsa")
("no grid" "nincs rcs")
("no indentation" "nincs behzs")
("no line break" "nincs sortrs")
("no matches found" "nincs tallat")
("no matches found for" "nincs tallat:")
("no more matches for" "nincs tbb tallat:")
("no more redo information available" "nincs tbb elrhet visszavonsi informci")
("no more undo information available" "nincs tbb elrhet visszavonsi informci")
("no name" "nvtelen")
("no page break after" "")
("no page break before" "")
("no spelling errors found in text" "nem tallhat helyesrsi hiba a szvegben")
("no style" "nincs stlus")
("none" "nincs")
("normal" "normlis")
("norwegian" "norvg")
("not" "nem")
("not equal" "nem egyenl")
("not found" "nem tallhat")
("notation" "jellsmd")
("note" "jegyzet")
("november" "november")
("number" "szm")
("number of columns" "oszlopok szma")
("number equation" "egyenlet szmozsa")
("numbered equation" "szmozott egyenlet")
("numbered equations" "szmozott egyenletek")
("numerator" "szmll")
("numeric" "")
("objectives" "clok")
("occurrences" "elfordulsok")
("october" "ektber")
("odd page footer" "pratlan oldal lblce")
("odd page header" "pratlan oldal fejlce")
("odd page margin" "pratlan oldal margi")
("odd page left margin" "pratlan oldal bal oldali margja")
("odd page right margin" "pratlan oldal jobb oldali margja")
("odd page shift" "")
("odd page text" "szveg pratlan oldalon")
("off" "ki")
("ok" "ok")
("old english" "rgi angol")
("old slavonic" "rgi szlv")
("old style" "rgi stlus")
("on" "be")
("on cells" "cellkra")
("on columns" "oszlopokra")
("on entire table" "teljes tblzatra")
("on rows" "sorokra")
("on the footer" "a lblcre")
("one spelling error has been corrected" "javtva egy helyesrsi hiba")
("online documentation" "online dokumentci")
("online help" "online segtsg")
("only inline tags" "csak a sorkzi cmkket")
("open" "megnyits")
("open a new buffer" "j puffer megnyitsa")
("open new window" "j ablak megnyitsa")
("opening" "megnyits")
("operation mode" "mkdsi md")
("operation on named selection" "")
("operation on primary selection" "mvelet elsdleges kivlasztson")
("operation on secondary selection" "mvelet msodlagos kivlasztson")
("operation on ternary selection" "mvelet harmadlagos kivlasztson")
("optical" "optikai")
("option" "opci")
("options" "opcik")
("or" "vagy")
("orange" "narancs")
("orientation" "tjols")
("origin" "")
("original welcome message" "eredeti dvzlszveg")
("other" "egyb")
("other pages" "msik oldalon")
("other projects" "egyb projektek")
("other style" "egyb stlus")
("outlined roman" "")
("over" "fellre")
("overbrace" "kapcsos zrjel fellre")
("overline" "fellvons")
("overview of the scheme extension language" "a Scheme kiegszt programnyelv ttekintse")
("owner" "tulajdonos")
("padding" "helykitlts")
("page" "oldal")
("page bottom margin" "oldal als margja")
("page break" "oldaltrs")
("page break before" "oldaltrs ez el")
("page height" "oldalmagassg")
("page insertion" "beszrs az oldalra")
("page layout" "oldal elrendezse")
("page number text" "oldalszm szvege")
("page numbering" "oldalszmozs")
("page reference" "oldalhivatkozs")
("page right margin" "oldal jobb margja")
("page setup" "oldalbellts")
("page top margin" "oldal fels margja")
("page type" "oldaltpus")
("page width" "oldalszlessg")
("paper" "papr")
("paper type" "paprtpus")
("papyrus" "papirusztekercs")
("paragraph" "bekezds")
("paragraph mode" "bekezdsmd")
("paragraph width" "bekezds szlessge")
("parametric curve" "paramteres grbe")
("parametric surface" "paramteres felszn")
("part" "rsz")
("past changes" "korbbi vltoztatsok")
("paste" "beilleszts")
("paste from" "beilleszts innen")
("paste text" "szveg beillesztse")
("path" "tvonal")
("perform operations on cells" "mveletek vgrehajtsa cellkon")
("perform operations on columns" "mveletek vgrehajtsa oszlopokon")
("perform operations on entire table" "mveletek vgrehajtsa a teljes tblzaton")
("perform operations on rows" "mveletek vgrehajtsa sorokon")
("permanent" "lland")
("permissions" "engedlyek")
("person" "szemly")
("personal dictionary has been modified" "a szemlyes sztr mdosult")
("phantasy" "fantzia")
("philosophy" "filozfia")
("phoenician" "fnciai")
("phonetic" "fonetikus")
("pink" "rzsaszn")
("plain block" "sima blokk")
("plain tabular" "sima tblzatos krnyezet")
("planned changes" "tervezett vltoztatsok")
("plans for the future" "tervek a jvre nzve")
("please" "krem")
("please wait" "krem, vrjon")
("plot" "bra")
("plugin" "bvtmny")
("plugins" "bvtmnyek")
("plus" "plusz")
("point" "pont")
("point style" "pontstlus")
("polar" "polris")
("polish" "lengyel")
("polygon" "sokszg")
("porting TeXmacs to other platforms" "a TeXmacs ms platformokra trtn portolsa")
("portrait" "ll")
("portuguese" "portugl")
("position" "pozci")
("position float" "lebeg objektum elhelyezse")
("position floating object" "lebeg objektum elhelyezse")
("position the table" "tblzat elhelyezse")
("postscript" "postscript")
("postscript image" "postscript kp")
("pre-alpha release" "alfa eltti vltozat")
("preamble" "elsz")
("preamble mode" "preamble md")
("preferences" "belltsok")
("presentation" "bemutat")
("presentation mode" "bemutatmd")
("presentation tag" "dsztsjelz cmke")
("preview before printing" "nyomtatsi elnzet")
("preview command" "elnzeti parancs")
("preview with ghostview" "elnzet ghostview-val")
("previous" "elz")
("primary" "elsdleges")
("prime" "")
("print" "nyomtats")
("print all" "minden kinyomtatsa")
("print all to file" "minden kinyomtatsa fjlba")
("print page selection" "kivlasztott oldalok nyomtatsa")
("print page selection to file" "kivlasztott oldalak nyomtatsa fjlba")
("print to postscript file" "nyomtats postscript fjlba")
("printer" "nyomtat")
("printer dpi" "nyomtat dpi")
("printing command" "nyomtatsi parancs")
("problem" "problma")
("professional" "professzionlis")
("prog" "")
("prog font" "")
("prog font family" "")
("prog font series" "")
("prog font shape" "")
("program" "program")
("program font" "")
("program mode" "")
("programming" "programozs")
("progressive" "")
("project" "projekt")
("projects" "projektek")
("prologue" "elsz")
("prompt on scripts" "rkrdezs")
("prompts and default input" "promptok s alaprtelmezett bemenet")
("proof" "bizonyts")
("properties" "tulajdonsgok")
("proportional" "arnyos")
("proportional typewriter" "arnyos rgp")
("proposition" "")
("query replace" "")
("quit" "kilps")
("quotation" "idzet")
("quote" "")
("range" "tartomny")
("rank" "rang")
("read" "olvass")
("really close it" "Biztosan be akarja zrni")
("really huge" "igazn risi")
("really quit" "valban ki szeretne lpni")
("really tiny" "igazn apr")
("recover autosave file" "Visszalltsuk a fjlt az automatikus mentsbl")
("red" "piros")
("redo" "mgis")
("redo undone changes" "visszavont vltoztatsok jraalkalmazsa")
("reduce bottom margin by" "")
("reduce left margin by" "")
("reduce margins" "margk cskkentse")
("reduce right margin by" "")
("reduce top margin by" "")
("reduce trigonometric functions" "")
("reduction even page margin" "")
("reduction odd page margin" "")
("reduction page bottom margin" "")
("reduction page right margin" "")
("reduction page top margin" "")
("reference" "hivatkozs")
("reference guide" "hivatkozsi kziknyv")
("reference guide for the TeXmacs primitives" "")
("reference guide for the standard TeXmacs styles" "")
("references" "")
("regular" "")
("release" "")
("reload" "jratlts")
("remark" "megjegyzs")
("remote" "tvoli")
("remote connections" "tvoli kapcsolatok")
("remove" "eltvolts")
("remove all output fields" "")
("remove fields" "mezk eltvoltsa")
("remove input field" "beviteli mez eltvoltsa")
("remove input field above" "")
("remove number" "szm eltvoltsa")
("remove package" "csomag eltvoltsa")
("remove this switch" "")
("renumber this page" "a lap jraszmozsa")
("repeat" "ismtls")
("repeat object" "")
("replace" "csere")
("replace by" "")
("replace unrecognized styles" "ismeretlen stlusok cserje")
("replaced" "")
("replaced one occurrence" "egy elforduls cserlve")
("reset" "")
("resize object" "objektum tmretezse")
("resized" "tmretezve")
("search results for" "keressi eredmnyek:")
("return" "")
("revert" "visszallts")
("revert buffer" "puffer visszalltsa")
("right" "jobb")
("right arrow" "nyl jobbra")
("right border" "jobb oldali keret")
("right cell border" "jobb oldali cellakeret")
("right cell padding" "jobb oldali cella helykitlts")
("right margin" "jobb oldali marg")
("right padding" "jobb oldali helykitlts")
("right aligned" "jobbra igaztva")
("right subscript" "jobb als index")
("right superscript" "jobb fels index")
("right surrounding" "")
("right table border" "jobb oldali tblzatkeret")
("right table padding" "jobb oldali tblzat helykitlts")
("rigid" "merev")
("rigid horizontal" "")
("rigid space" "nem trhet szkz")
("romanian" "romn")
("root" "gyk")
("rotate backward" "forgats visszafel")
("rotate forward" "forgats elre")
("round" "res kerek")
("row" "sor")
("row above" "sor fellre")
("row below" "sor alulra")
("row contains glued items" "")
("rows" "sorok")
("runic" "rovsrsos")
("running author" "")
("running title" "")
("russian" "orosz")
("sample" "minta")
("sans serif" "sans serif")
("save" "ments")
("save TeXmacs file" "TeXmacs fjl mentse")
("save TeXmacs style file" "TeXmacs stlusfjl mentse")
("save as" "ments msknt")
("save as LaTeX" "ments LaTeX-knt")
("save as TeX" "ments TeX-knt")
("save buffer" "puffer mentse")
("save buffer as" "puffer mentse msknt")
("save file" "fjl mentse")
("save html file" "html fjl mentse")
("save image" "kp mentse")
("save latex file" "latex fjl mentse")
("save tex file" "tex fjl mentse")
("save this buffer" "az aktulis puffer mentse")
("save verbatim file" "verbatim fjl mentse")
("saved" "elmentve")
("scheme command" "scheme parancs")
("scheme extensions" "scheme kiterjesztsek")
("screen layout" "elrendezs a kpernyn")
("screen margins" "margk a kpernyn")
("script" "index")
("script above" "index fellre")
("script below" "index alulra")
("script script size" "index indexnek mrete")
("script size" "index mrete")
("scripts" "szkriptek")
("scripts not accepted" "a szkriptek nincsenek engedlyezve")
("search" "keress")
("search words in my documents" "szavak keresse a sajt dokumentumaimban")
("search words in the documentation" "szavak keresse a dokumentciban")
("search words in the source code" "szavak keresse a forrskdban")
("searching" "keress")
("secondary" "msodlagos")
("section" "szekci")
("security" "biztonsg")
("see" "lsd")
("select a document style" "vlasszon dokumentumstlust")
("select a foreground color" "vlasszon eltrsznt")
("select a language" "vlasszon nyelvet")
("selected region" "kivlasztott terlet")
("selection" "kijells")
("selections" "kijellsek")
("seminar" "")
("sending commands to TeXmacs" "parancsok kldse a TeXmacs-nak")
("separation between lines" "")
("separation between paragraphs" "")
("separator" "elvlaszt")
("september" "szeptember")
("serb" "szerb")
("series" "sorozat")
("series|right" "")
("session" "kls munkamenet")
("session name" "kls munkamenet neve")
("session type" "kls munkamenet tpusa")
("sessions" "kls munkamenetek")
("set" "")
("set background color of cell" "cella httrsznnek belltsa")
("set cell mode" "cella mdjnak belltsa")
("set extension center" "")
("set height" "magassg belltsa")
("set height of cell" "cella magassgnak belltsa")
("set margins" "margk belltsa")
("set n" "n belltsa")
("set or get environment variables" "krnyezeti vltozk belltsa vagy lekrdezse")
("set paragraph margins" "bekezdsmargk belltsa")
("set paragraph mode" "bekezdsmd belltsa")
("set printer dpi" "nyomtatsi felbonts (dpi) belltsa")
("set printing command" "nyomtatsi parancs belltsa")
("set span" "")
("set special cell properties" "specilis cellatulajdonsgok belltsa")
("set special table properties" "specilis tblzattulajdonsgok belltsa")
("set text width" "szvegszlessg belltsa")
("set width" "szlessg belltsa")
("set width of cell" "cellaszlessg belltsa")
("settings" "belltsok")
("setup printer" "nyomtat belltsa")
("shape" "alak")
("shift-down" "shift-le")
("shift-right" "shift-jobbra")
("short" "rvid")
("show" "")
("show all parts" "sszes rsz mutatsa")
("show header and footer" "fejlc s lblc mutatsa")
("show hidden" "rejtettek mutatsa")
("show on screen" "megmutats kpernyn")
("show one part" "egy rsz mutatsa")
("show several parts" "nhny rsz mutatsa")
("shrinking factor" "nagytsi tnyez")
("signature" "alrs")
("simple" "egyszer")
("simplify" "egyszersts")
("simplification" "egyszersts")
("simplified evaluation of formulas" "kpletek egyszerstett kirtkelse")
("simplified menus" "egyszerstett menk")
("sine" "szinusz")
("size" "mret")
("size limits" "mrethatrok")
("size tag" "mretjelz cmke")
("slanted" "ferde")
("sloppy" "")
("slovene" "szlovn")
("small" "kicsi")
("small caps" "kiskapitlis")
("small figure" "kis bra")
("small skip" "kis helykihagys")
("small table" "kis tblzat")
("sound" "hang")
("source" "forrs")
("source code" "forrskd")
("source tags" "forrskd-cmkk")
("space" "trkz")
("space between lines" "sortvolsg")
("space between paragraphs" "bekezdsek kzti tvolsg")
("spacing" "trkzk")
("spanish" "spanyol")
("special" "specilis")
("special cell properties" "specilis cellatulajdonsgok")
("special functions" "specilis fggvnyek")
("special properties" "specilis tulajdonsgok")
("special table properties" "specilis tblzattulajdonsgok")
("specific" "specific parancs")
("specify the size of the table" "adja meg a tblzat mrett")
("spell" "helyesrs")
("spell checking complete" "a helyesrs ellenrzse befejezdtt")
("spelling error" "helyesrsi hiba")
("spelling errors have been corrected" "helyesrsi hiba javtva")
("split" "")
("split session" "")
("square" "szgletes")
("square root" "ngyzetgyk")
("standard environment variables" "standard krnyezeti vltozk")
("standard formats" "standard formtumok")
("standard TeXmacs styles" "standard TeXmacs stlusok")
("start" "")
("start a new chapter" "j fejezet kezdse")
("start a new section" "j szekci kezdse")
("start an interactive session" "interaktv munkamenet kezdse")
("status bar" "lblc")
("stretch" "nyjts")
("stretchable" "nyjthat")
("stretchable horizontal" "vzszintesen nyjthat")
("stretchable vertical" "fgglegesen nyjthat")
("stretched" "nyjtott")
("stroke" "vons")
("strokes" "vons")
("strong" "vastagtott")
("structural" "")
("style" "stlus")
("styles" "stlusok")
("stylesheet language" "stluslap-nyelv")
("sub" "albejegyzs")
("subparagraph" "albekezds")
("subscript" "als index")
("subsection" "alszekci")
("subsub" "al-albejegyzs")
("subsubsection" "al-alszekci")
("subtable" "altblzat")
("subtitle" "alcm")
("summary" "sszefoglals")
("summary of the principal TeXmacs tags" "")
("superpose" "")
("superposed" "")
("superscript" "fels index")
("surface" "felszn")
("swedish" "svd")
("swiss" "svjci")
("switch" "vlts")
("switch to first" "vlts az elsre")
("switch to formula style" "vlts kpletstlusra")
("switch to last" "vlts az utolsra")
("switch to next" "vlts a kvetkezre")
("switch to previous" "vlts az elzre")
("switching and folding" "")
("symbol" "szimblum")
("system command" "rendszerparancs")
("system environment variables" "krnyezeti vltozk")
("tab" "tabultor")
("table" "tblzat")
("table command" "tblzatparancs")
("table height" "tablzat magassga")
("table of contents" "tartalomjegyzk")
("table width" "tblzatszlessg")
("tables" "tblzatok")
("tabular" "tblzatos krnyezet")
("tabular material" "tblzatok")
("taiwanese" "taiwani")
("tangent" "tangens")
("target" "cl")
("teXmacs as an interface" "a texmacs mint felhasznli fellet")
("teXmacs fonts" "teXmacs bettpusok")
("teXmacs notice" "")
("teXmacs plugins" "teXmacs bvtmnyek")
("teXmacs primitives" "a TeXmacs alapvet ptelemei")
("teXmacs style files" "teXmacs stlusfjlok")
("ternary" "harmadlagos")
("test" "tesztels")
("tex" "tex")
("TeXmacs fonts" "TeXmacs bettpusok")
("text" "szveg")
("text box" "szvegdoboz")
("text box alignment" "szvegdoboz igaztsa")
("text box horizontal alignment" "szvegdoboz vzszintes igaztsa")
("text box vertical alignment" "szegdoboz fggleges igaztsa")
("text font" "szveg bettpusa")
("text height correction" "szvegmagassg korriglsa")
("text width" "szvegszlessg")
("texts" "texts knyvtr")
("th century bc" " szzad Kr. e.")
("th root" "-ik gyk")
("thai" "thai")
("the TeXmacs authors" "a TeXmacs szerzi")
("the TeXmacs format" "a TeXmacs formtuma")
("the application did not send its usual startup banner" "az alkalmazs nem kldte el a szoksos bejelentkez zenett")
("the application does not reply" "az alkalmazs nem vlaszol")
("the application is already running" "az alkalmazs mr fut")
("the boxes produced by the typesetter" "a szed ltal ksztett dobozok")
("the document has not been saved" "a puffer nincs elmentve")
("the graphical user interface" "a grafikus felhasznli fellet")
("the leaves of TeXmacs trees" "")
("the mycas example" "a mycas plda")
("the primitive TeXmacs constructs" "")
("the standard TeXmacs styles" "a standard TeXmacs stlusok")
("theorem" "ttel")
("there are unsaved documents" "vannak mentsre vr fjlok")
("this document has not been saved" "ez a puffer mg nincs elmentve")
("this column" "ez az oszlop")
("this document has been produced using" "")
("this line" "ezt a sort")
("this page" "ezt az oldalt")
("this page footer" "ezt az llbat")
("this page header" "ezt az lfejet")
("this row" "ezt a sort")
("thumbnails" "elnzeti kpek")
("tilda" "tilda")
("tilde" "tilde")
("times" "times")
("timings" "idztsek")
("tiny" "apr")
("title" "cm")
("to the left" "balra")
("to the right" "jobbra")
("today" "ma")
("tools" "eszkzk")
("top" "fell")
("top border" "keret fell")
("top cell border" "cellakeret fell")
("top cell padding" "")
("top level" "")
("top margin" "marg fell")
("top padding" "")
("top table border" "tblzatkeret fell")
("top table padding" "")
("transfer" "transzfer")
("translate" "elfordts")
("transpose" "transzponls")
("tree" "fa")
("triangularize" "hromszgels")
("trigonometric" "trigonometrikus")
("trigonometry" "trigonometria")
("tuple" "n-es")
("turkish" "trk")
("tutorial" "bevezet")
("type" "tpus")
("type 1 only" "csak Type 1")
("type a latex command followed by" "")
("type body" "")
("type denominator" "adja meg a nevezt")
("type numerator" "adja meg a szmllt")
("type script" "")
("typesetted boxes" "")
("typewriter" "rgp")
("typewriter small caps" "rgp kiskapitlis")
("typing a simple text" "egyszer szveg gpelse")
("typing simple texts" "egyszer szvegek gpelse")
("ugaritic" "")
("ukrainian" "ukrn")
("underbrace" "kapcsos zrjel alulra")
("underline" "alhzs")
("undo" "visszavons")
("undo last changes" "utols vltoztatsok visszavonsa")
("ungroup" "csoport felbontsa")
("unit" "mrtkegysg")
("unzoom" "kicsinyts")
("up" "fel")
("update" "aktualizls")
("update from web" "")
("update image links" "kphivatkozsok aktualizlsa")
("upper border" "")
("upright" "egyenes")
("url" "url")
("use MathML" "MathML hasznlata")
("use TeXmacs" "hasznlja a TeXmacs-et")
("use a black color" "")
("use a blue color" "")
("use a bold font" "")
("use a brown color" "")
("use a calligraphic font" "")
("use a green color" "")
("use a grey color" "")
("use a magenta color" "")
("use a orange color" "")
("use a pink color" "")
("use a red color" "")
("use a sans serif font" "sans serif bettpus hasznlata")
("use a typewriter font" "")
("use a white color" "")
("use a yellow color" "")
("use blackboard bold font" "")
("use bold font series" "flkvr betsorozat hasznlata")
("use calligraphical font" "kalligrafikus bettpus hasznlata")
("use footnote font size" "")
("use fraktur font" "")
("use huge font size" "risi betmret hasznlata")
("use italic font shape" "dlt betalak hasznlata")
("use large font size" "nagy betmret hasznlata")
("use left hand column as border" "")
("use medium font series" "")
("use normal font size" "")
("use package" "csomag hasznlata")
("use paragraph width" "")
("use really huge font size" "tnyleg risi betmret hasznlata")
("use right font shape" "")
("use right hand column as border" "")
("use roman font family" "roman betcsald hasznlata")
("use row above as border" "")
("use row below as border" "az als sor hasznlata keretknt")
("use sans serif font family" "")
("use script font size" "")
("use slanted font shape" "")
("use small capitals" "kiskapitlis hasznlata")
("use small font size" "")
("use small-caps font shape" "")
("use the blackboard bold font" "")
("use the fraktur font" "")
("use tiny font font size" "")
("use typewriter font family" "")
("use very large font size" "")
("user manual" "felhasznli kziknyv")
("user provided icons" "felhasznli ikonok")
("users of Cyrillic languages" "cirillbets nyelvek")
("users of oriental languages" "keleti nyelvek")
("utilities" "segdeszkzk")
("value" "rtk")
("variable" "vltoz")
("variant" "vltozat")
("vector" "vektor")
("verbatim" "")
("verse" "versszak")
("vertical" "fggleges")
("vertical after" "fggleges, ez utn")
("vertical alignment" "fggleges igazts")
("vertical before" "fggleges, ez el")
("vertical cell alignment" "fggleges cellaigazts")
("vertical part" "fggleges rsz")
("vertical position" "fggleges pozci")
("vertical space" "fggleges trkz")
("vertical table alignment" "fggleges tblzatigazts")
("vertically align cell to the base" "")
("vertically center the cell" "cella kzpre igaztsa fgglegesen")
("very large" "nagyon nagy")
("very small" "nagyon kicsi")
("vietnamese" "vietnmi")
("view" "nzet")
("visible" "lthat")
("warning" "figyelmeztets")
("web" "web")
("welcome" "dvzlet")
("welcome to GNU TeXmacs" "dvzli a GNU TeXmacs")
("what is new" "jdonsgok")
("when finished" "ha ksz")
("while" "while")
("white" "fehr")
("wide accent" "szles hangslyjel")
("wide bar" "")
("width" "szlessg")
("width is exactly the specified width" "a szlessg pontosan a meghatrozott rtk")
("width is maximum of specified width and box width" "a szlessg a meghatrozott rtk s a doboz szlessge kzl a nagyobb")
("width is minimum of specified width and box width" "a szlessg a meghatrozott rtk s a dboz szlessge kzl a kisebbik")
("width magnification" "szlessg nagytsa")
("window" "ablak")
("window height" "ablakmagassg")
("window width" "ablakszlessg")
("windows key" "windows billenty")
("with" "")
("wrap lines" "sortrs")
("write" "rs")
("write a macro" "makr ksztse")
("write a name" "")
("write bold mathematics" "dlt matematikai szveg ksztse")
("write bold text" "flkvr szveg")
("write italic text" "dlt szveg")
("write sample text" "")
("write strong text" "")
("write typewriter text" "")
("write verbatim text" "")
("writing data converters" "adattalaktk ksztse")
("writing your own style files" "sajt stlusfjlok ksztse")
("written with TeXmacs" "kszlt a TeXmacs szoftverrel")
("yellow" "srga")
("you can also obtain" "")
("your document is back in its original state" "megtrtnt a dokumentum eredeti llapotba visszalltsa")
("your first interface" "")
("your language" "az n nyelve")
("zoom" "nagyts")
